;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "visual-shorthands" "20260104.2221"
  "Visual abbreviations for symbol prefixes."
  '((emacs "29.1"))
  :url "https://github.com/gggion/visual-shorthands.el"
  :commit "0511154773533ec2e3c25efa5515ea548ee7e9e1"
  :revdesc "051115477353"
  :keywords '("convenience")
  :maintainers '(("Gino Cornejo" . "gggion123@gmail.com")))
